---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: bug
assignees: steven-murray

---

**Describe the bug**
<! -- A clear and concise description of what the bug is. -->

**To Reproduce**
Steps to reproduce the behavior:
1. ...
2. ...

**Expected behavior**
<! -- A clear and concise description of what you expected to happen. -->

**Details:**
 - OS: [e.g. iOS]
 - Version [e.g. 22]

**Additional context**
<! -- Add any other context about the problem here. -->
